Learn R Programming

pSI (version 1.0)

dataset.s1: Supplementary Data Set 1

Description

Differentially expressed genes (up-regulated & down-regulated) in cortices of autsitic vs control subjects from human transcriptomic data.

Arguments

format

List containing two character vectors

source

Voineagu I, Wang X, Johnston P, Lowe JK, Tian Y, Horvath S, et al. (2011): Transcriptomic analysis of autistic brain reveals convergent molecular pathology. Nature. 474:380-384.

item

dataset.s1$down.regulated

cr

- Down-regulated genes (N=229)

Details

dataset.s1 is a list which contains two character vectors of differentially expressed genes. Differential expression was assessed using the SAM package (Significance Analysis of Microarrays), for FDR <.05 and="" fold="" change="">1.3.
  • dataset.s1$up.regulated
Up-regulated genes (N=234)

Examples

Run this code
data(dataset.s1)

Run the code above in your browser using DataLab