Learn R Programming

pSI (version 1.0)

fisher.iteration: Fisher's Exact Test Across All Cell Types & pSI Thresholds

Description

fisher.iteration will test a candidate gene list for overrepresenation in the various cell type/pSI threshold combinations produced by the specificty.index function. NOTE:Supplementary data (supplementary tables,human & mouse expression sets, calculated pSI datasets, candidate gene lists, etc.) can be found in pSI.data package.

Usage

fisher.iteration(pSIs, candidate.genes, background = "data.set",
  p.adjust = TRUE)

Arguments

pSIs
data frame output from specificity.index function with the number of columns equal to the number of samples and genes as rows.
candidate.genes
candidate gene list tested for overrepresentation in cell types/samples. Comprised of official gene symbols.
background
character string used to indicate what background gene list should be used in Fisher's exact test for overrepresentation. The default value is "data.set" which indicates that the gene list of the input pSI data set will be used to rep
p.adjust
logical. default output is bonferroni corrected p-value but if p.adjust is FALSE, nominal p-values will be output.

Details

This function is used to answer the question of what is the probability that a certain number of genes specific to a certain cell type/sample occured by chance (as usual with low probabilities corresponding to high statistical significance). This is accomplished with a binary variable for each gene in the population with two mutual exclusive values: 1) The gene is specific to the cell type/sample in question or 2) The gene is not specific to the cell type/sample in question

Examples

Run this code
##load sample pSI output
data(sample.data)
##load sample candidate gene lists
data(candidate.genes)
##run Fisher's exact test for overrperesentation on pSI.out for the AutDB
##candidate gene list across all cell types/sample types & pSI thresholds
fisher.out.AutDB <- fisher.iteration(sample.data$pSI.output, candidate.genes$AutDB)

Run the code above in your browser using DataLab