pSI.list returns list consisting of 6 data frames,
one for each pSI threshold.
Usage
pSI.list(pSIs, write.csv = TRUE)
Arguments
pSIs
data frame output from
specificity.index function with the number of
columns equal to the number of samples and genes as
rows.
write.csv
logical variable indicating if csv files
will be written to the current working directory (default
value is FALSE)
Details
Each data frame contains genes whose pSI values fall below
each respective threshold for each cell type/sample
included in the analysis. NOTE:Supplementary data
(supplementary tables,human & mouse expression sets,
calculated pSI datasets, candidate gene lists, etc.) can be
found in pSI.data package.
##load sample pSI outputdata(sample.data)
##List the genes specific to each cell type/sample type across all pSI thresholdspSI.out.list <- pSI.list(pSIs=sample.data$pSI.output, write.csv=FALSE)